@@ -40,5 +40,5 @@
   (if (> (length args-list) 1)
       (set! forward (assoc-set! forward (car args-list) (cdr args-list)))
       (begin (display "?forward: wrong number of arguments\n") 
-	     (display "usage: ?forward buddy-name forward-list"))))
+	     (display "usage: ?forward buddy-name forward-list\n"))))
 
