@@ -31,6 +31,12 @@
   (if (string=? "gnubot" (fh-get-default-login-id))
       (fh-load "gnubot.scm")))
 
+(define (?dbg-backtrace args)
+  "produce a backtrace of last error"
+  (backtrace))
+(fh-register-command! '("?dbg-backtrace" "?dbg-backtrace\n\t- produce a backtrace of last error"))
+
+
 (catch #t
        (lambda ()
 	 ;; set gnu prompt
@@ -53,10 +59,12 @@
 	 (fh-load "conference.scm")
 	 (fh-load "history.scm")
 	 (fh-load "shell.scm")
+	 (fh-load "pipe.scm")
 	 (fh-load "ping.scm")
 	 (fh-load "proud-of-freehoo.scm")
 	 (fh-load "broadcast.scm")
 	 (fh-load "xmessage.scm")
+	 (fh-load "mr-oxford.scm")
 	 (if (= (system "dict gnu >> /dev/null 2>&1") 0)
 	     (fh-load "dict-buddy.scm"))
 	 (if (= (system "beep -f 1 -l 0 >> /dev/null 2>&1") 0)
@@ -76,3 +84,4 @@
 	 (newline)
 	 (backtrace)
 	 (newline)))
+
