@@ -109,7 +109,6 @@
 ;;  	   (skip-comment port))
 	  (else char))))
 
-
 (define (read-token port delim)
   (letrec
       ((loop
@@ -250,3 +249,11 @@
        (mm (substring date-str 2 4))
        (dd (substring date-str 4 6)))
     (map string->number (list yy mm dd))))
+
+(define (for-each-line proc filename)
+  "call PROC for each line in FILENAME"
+  (with-input-from-file filename
+    (lambda ()
+      (do ((line (read-line) (read-line)))
+          ((eof-object? line))
+        (proc line)))))
