@@ -332,6 +332,24 @@ install_new_procedures (void)
   /* this way you call me
      (fh-logoff)
   */
+
+  /* add new word for dictionary autocomplete */
+  gh_new_procedure ("fh-dict-add-word!", ex_fh_dict_add_word, 1, 0, 0);
+  /* this way you call me
+   * (fh-dict-add-word! "newbigword")
+   */
+
+  /* add new word for dictionary autocomplete in pre sorted sequence */
+  gh_new_procedure ("fh-dict-add-word-sorted!", ex_fh_dict_add_word_sorted, 1, 0, 0);
+  /* this way you call me
+   * (fh-dict-add-word-sorted! "newbigword")
+   */
+
+  /* delete word from automplete dictionary */
+  gh_new_procedure ("fh-dict-del-word!", ex_fh_dict_del_word, 1, 0, 0);
+  /* this way you call me
+   * (fh-dict-del-word! "easy")
+   */
 }
 
 // guile initialization area
