@@ -48,7 +48,7 @@ char *default_prompt = FH_PROMPT_STRING;
 int setup_mode = 0;
 int yes_gnubot = 0;
 
-typedef void (*sighandler_t) (int);
+/* typedef void (*sighandler_t) (int); */
 
 /* Program documentation. */
 static char doc[] = "FreeHoo! is a freely available GNU messenger for \
@@ -271,7 +271,6 @@ inner_main (int argc, char **argv)
 
   /* <<< GUILE INITIALIZATION ENDS */
 
-
   // ACTUAL MAIN STARTS FROM HERE
   messenger_main (argc, argv);
 
