@@ -54,7 +54,7 @@ char * autocomplete_buddy_regex =
 		"^\\ *\\?("
 		
                /* commands which accept 1st arg as buddy */
-		"send|send\\-file|ignore|unignore|add|remove|reject|color\\-buddy|ping|buzz|forward|vconf\\-start|xmessage|"
+		"send|send\\-file|ignore|unignore|add|remove|reject|color\\-buddy|ping|buzz|forward|vconf\\-start|xmessage|freehoo|"
 		
 		/* commands which accpet 1st arg and beyond as buddies */
 		"(forward|vconf\\-start)\\ +[a-zA-Z0-9_\\-\\ ]*|" 
@@ -90,15 +90,15 @@ char * autocomplete_file_regex =
                 /* regex header */
 		"^\\ *\\?("
 		
-               /* commands which accept 1st arg as filename*/
-		"send\\-file"
-		
-		/* buddy name */
-		")\\ +[a-zA-Z0-9_\\-]+\\ +" 
+          /* commands which accept 2nd arg as filename*/
+		"(send\\-file|send\\-newfile)\\ +[a-zA-Z0-9_\\-]+\\ +)|" 
+
+          /* commands which accept 1st arg as filename*/
+        "load|loadconfig"
 
 		/* regex footer, possibly along with the 
 		 * half filename*/
-		"[a-zA-Z0-9_\\-\\/\\.]*$" ;
+		")\\ +[a-zA-Z0-9_\\-\\/\\.]*$" ;
 
 char * autocomplete_cmd_regex = 		
                 /* still in first word or no words yet*/
@@ -116,6 +116,7 @@ int current_status = -1;   // status not set
 
 char *current_status_custom_message = (char *) NULL;   // NULL means not set
 extern GHashTable *fh_buddy_list;
+struct dict_words *word_list = NULL;
 
 unsigned char
 get_bell_state (void)
@@ -268,11 +269,13 @@ command_generator (const char *text, int state)
   regex_t preg;
   char curr_char = rl_line_buffer[rl_point];
   conf_room *rooms;
-  YList *conflist = NULL;
+  static YList *conflist = NULL;
+  static struct dict_words *dw;
   static char complete_buddy = 0,
 	      complete_conf = 0,
 	      complete_toggle = 0,
 	      complete_file = 0,
+	      complete_dict = 0,
               complete_cmd = 0; // flags because regex is expensive
 
   if (!state)
@@ -288,7 +291,7 @@ command_generator (const char *text, int state)
       complete_cmd = 0;
       complete_file = 0;
       conflist = get_fh_conferences();
-
+      dw = NULL;
      
       rl_line_buffer[rl_point] = '\0'; /* the effect should be such
 					 * that the cursor position
@@ -339,7 +342,13 @@ command_generator (const char *text, int state)
 	/* if no context available, default to buddy completion */
 	if(!complete_buddy && !complete_cmd && !complete_conf && !complete_cmd && !complete_file && !complete_toggle) 
         {
-          /* complete_buddy = 1; */
+             complete_dict = 1;
+             dw = word_list;
+	     while (dw) {
+                if (!strncmp (dw->word, text, strlen (text)))
+                    break;
+                dw = dw->next;
+	     }
         }
 
        rl_line_buffer[rl_point] = curr_char; /* what effect? :-) */
@@ -366,13 +375,13 @@ command_generator (const char *text, int state)
     if ( complete_conf)
     {
        /* conf rooms */
-       if(conflist) 
+       while(conflist) 
        {
          rooms = (conf_room *)conflist->data;
+         conflist = conflist->next;
          if(rooms && rooms->room_name && 
              !strncasecmp(rooms->room_name,text,len))
             return strdup(rooms->room_name);
-         conflist = conflist->next;
        }
     }
 
@@ -426,6 +435,17 @@ command_generator (const char *text, int state)
 	   return (char *) strdup (name);
         }
     }
+
+    if (complete_dict)
+    {
+	if (dw && !strncmp(dw->word, text, strlen(text))) {
+            char *ret = dw->word;
+            dw = dw->next;
+	    return strdup(ret);
+	} else {
+            dw = NULL;
+	}
+    }
   
     return (char *) NULL; /* in the end */
 }
