@@ -164,7 +164,7 @@ get_local_addresses ()
   FILE *f;
 
   f = popen ("netstat -nr", "r");
-  if ((int) f < 1)
+  if (f == NULL)
     goto IP_TEST_2;
   while (fgets (buff, sizeof (buff), f) != NULL)
     {
@@ -196,7 +196,7 @@ get_local_addresses ()
 
   sprintf(popen_cmd,"/sbin/ifconfig %s",interface);
   f = popen (popen_cmd, "r");
-  if ((int) f < 1)
+  if (f == NULL)
     goto IP_TEST_2;
 
   while (fgets (buff, sizeof (buff), f) != NULL)
@@ -1607,7 +1607,7 @@ main_loop ()
 int
 messenger_main (int argc, char *argv[])
 {
-  int size = 0;
+  size_t size = 0;
   char *login_id = get_default_login_id ();
   char *password = get_default_password ();
 
